.. SPDX-FileCopyrightText: 2023-2024 Anna <cyber@sysrq.in>
.. SPDX-License-Identifier: WTFPL
.. No warranty.

API Reference
=============

This API reference is aimed at people who wish to contribute to gentle.

.. note::
   Python API is not covered by SemVer policy for this project and can be
   changed at any time.

.. autosummary::
    :toctree: api

    gentle.generators
    gentle.metadata
    gentle.pms
    gentle.utils
